@@ -31,7 +31,6 @@
 #include <libedataserverui/e-passwords.h>
 #include <mail/em-folder-tree.h>
 #include <mail/e-mail-backend.h>
-#include <mail/e-mail-store.h>
 #include <mail/em-folder-selector.h>
 #include <mail/em-account-editor.h>
 #include <mail/mail-ops.h>
@@ -423,15 +422,16 @@ proxy_login_add_new_store (CamelStore *store,
 {
 	EShell *shell;
 	EShellBackend *shell_backend;
-	EMailBackend *mail_backend;
-	EMailSession *mail_session;
+	EMailBackend *backend;
+	EMailSession *session;
+	EMailAccountStore *account_store;
 	gint permissions = GPOINTER_TO_INT(g_object_get_data ((GObject *)account, "permissions"));
 
 	shell = e_shell_get_default ();
 	shell_backend = e_shell_get_backend_by_name (shell, "mail");
 
-	mail_backend = E_MAIL_BACKEND (shell_backend);
-	mail_session = e_mail_backend_get_session (mail_backend);
+	backend = E_MAIL_BACKEND (shell_backend);
+	session = e_mail_backend_get_session (backend);
 
 	if (store == NULL)
 		return;
@@ -440,7 +440,9 @@ proxy_login_add_new_store (CamelStore *store,
 		store->mode &= !CAMEL_STORE_WRITE;
 
 	store->flags |= CAMEL_STORE_PROXY;
-	e_mail_store_add (mail_session, store);
+
+	account_store = e_mail_session_get_account_store (session);
+	e_mail_account_store_add_service (account_store, CAMEL_SERVICE (store));
 }
 
 static void
