@@ -92,12 +92,18 @@ shared_folder_commit (EPlugin *ep,
 	CamelStore *parent_store;
 	EMFolderTreeModel *model;
 	EShell *shell;
-	EMailBackend *mail_backend;
+	EShellBackend *shell_backend;
+	EMailBackend *backend;
+	EMailSession *session;
 
 	shell = e_shell_get_default ();
-	mail_backend = E_MAIL_BACKEND (e_shell_get_backend_by_name (shell, "mail"));
+	shell_backend = e_shell_get_backend_by_name (shell, "mail");
+
+	backend = E_MAIL_BACKEND (shell_backend);
+	session = e_mail_backend_get_session (backend);
+
 	model = em_folder_tree_model_new ();
-	em_folder_tree_model_set_backend (model, mail_backend);
+	em_folder_tree_model_set_session (model, session);
 
 	parent_store = camel_folder_get_parent_store (target->folder);
 
@@ -256,7 +262,7 @@ users_dialog_response (GtkWidget *dialog,
 	struct _EMFolderTreeModelStoreInfo *si;
 	EMFolderSelector *emfs = ssi->emfs;
 	EMFolderTree *folder_tree;
-	EMailBackend *mail_backend;
+	EMailSession *session;
 	CamelStore *store;
 	gchar *folder_name;
 
@@ -267,7 +273,7 @@ users_dialog_response (GtkWidget *dialog,
 	}
 
 	folder_tree = em_folder_selector_get_folder_tree (emfs);
-	mail_backend = em_folder_tree_get_backend (folder_tree);
+	session = em_folder_tree_get_session (folder_tree);
 
 	if (!em_folder_tree_get_selected (folder_tree, &store, &folder_name))
 		g_return_if_reached ();
@@ -281,7 +287,7 @@ users_dialog_response (GtkWidget *dialog,
 	if (CAMEL_IS_VEE_STORE (store)) {
 		EFilterRule *rule;
 
-		rule = em_vfolder_rule_new (mail_backend);
+		rule = em_vfolder_rule_new (session);
 		e_filter_rule_set_name (rule, folder_name);
 		vfolder_gui_add_rule (EM_VFOLDER_RULE (rule));
 		gtk_widget_destroy ((GtkWidget *) emfs);
@@ -353,15 +359,13 @@ gw_new_shared_folder_cb (GtkAction *action,
 {
 	EMFolderSelector *selector;
 	EMFolderTree *folder_tree;
-	EShellBackend *shell_backend;
 	GtkWidget *dialog;
 	gpointer parent;
 
 	parent = e_shell_view_get_shell_window (shell_view);
-	shell_backend = e_shell_view_get_shell_backend (shell_view);
 
 	dialog = em_folder_selector_create_new (
-		parent, E_MAIL_BACKEND (shell_backend), em_folder_tree_model_get_default (), 0,
+		parent, em_folder_tree_model_get_default (), 0,
 		_("Create folder"), _("Specify where to create the folder:"));
 
 	selector = EM_FOLDER_SELECTOR (dialog);
@@ -439,7 +443,6 @@ get_cnc (CamelStore *store)
 	const gchar *uri, *server_name, *user;
 	CamelService *service;
 	CamelSettings *settings;
-	CamelURL *url;
 	CamelNetworkSecurityMethod security_method;
 	const gchar *scheme;
 	const gchar *password;
@@ -449,14 +452,13 @@ get_cnc (CamelStore *store)
 		return  NULL;
 
 	service = CAMEL_SERVICE (store);
-	url = camel_service_get_camel_url (service);
 	password = camel_service_get_password (service);
 	settings = camel_service_get_settings (service);
-	server_name = g_strdup (url->host);
-	user = g_strdup (url->user);
 
 	g_object_get (
 		settings,
+		"user", &user,
+		"host", &server_name,
 		"soap-port", &soap_port,
 		"security-method", &security_method,
 		NULL);
